OiRA

Help

1. Sagatavošanās
2. Iesaiste
3. Identifikācija + Novērtēšana
4. Rīcības plāns
5. Pārskats
6. Statuss 0%

# Pārskatu veidošana

Tā kā esat beidzis identificēt organizācijā esošos riskus un izveidojis rīcības plānu, tagad varat izveidot pārskatu, kurā būs iekļauti visi rezultāti. Ja vēlaties, tālāk redzamajā laukā varat ierakstīt papildu komentārus, kas jāiekļauj pārskatā.

Saglabāt un turpināt

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More